declare global {
    interface String {
        capitalize(): string;
        hashCode(): number;
        parseList(prune: boolean, delimiter: string): string[];
        regexIndexOf(re: RegExp, start: number): number;
        rstrip(): string;
        splitInTwo(delimiter: string): [string, string];
        splitNL(): string[];
        trim(): string;
    }
}
/**
 * Capitalizes the first letter of a string and return it.
 *
 * ```javascript
 * import {capitalize} from 'util.string';
 *
 * capitalize('abc'); // 'Abc'
 * ```
 *
 * @param text {string} - the input string to cacpitalize
 * @return {string} - the newly capitalized string.
 */
export declare function capitalize(text: string): string;
/**
 * Converts a string to a 32bit int hash number.  Based on the djb2 algorithm:
 * http://www.cse.yorku.ca/~oz/hash.html
 *
 * ```javascript
 * import {hashCode} from 'util.string';
 *
 * const s = "the quick brown fox jumps over the lazy dog";
 * hashCode(s); // 1224788714
 * ```
 *
 * @param text {string} - the string to hash
 * @return {number} the new hash code related to the string as a 32-bit
 * unsigned int
 */
export declare function hashCode(text: string): number;
/**
 * Takes a Set of strings and converts it to a string that is joined by a
 * delimiter.  Note that this function is NOT monkey patched into the
 * String.prototype.
 *
 * @param obj {Set<string>} - the set of strings that will be joined together
 * @param delimiter="" {string} - the string value that will be placed between
 * each string as they are joined together.  This is empty by default.
 * @return {string} a new string of all sub objects joined together.
 */
export declare function join(obj: Set<string>, delimiter?: string): string;
/**
 * Takes a comma delimited string list, splits it into tokens and returns it
 * as an array of strings.  The whitespace is trimmed from each string and
 * empty strings are removed from the list by default (pruning).
 *
 * ```javascript
 * import {parseList} from 'util.string';
 * parseList("a, b, c");  // ["a", "b", "c"]
 * ```
 *
 * The pruning can be turned off by setting the second parameter to false
 *
 * ```javascript
 * parseList(", , a, b, c");  // ["", "", "a", "b", "c"]
 * ```
 *
 * @param text {string} - the string to parse
 * @param prune=true {boolean} - Removes empty strings from the array
 * if true, otherwise empty strings are not removed.
 * @param delimiter="," {string} - the character that will be used as the
 * split location.
 * @return {string[]} an array of strings generated from the split operation
 */
export declare function parseList(text: string, prune?: boolean, delimiter?: string): string[];
/**
 * Searches for the first location (index) within a given string using a regex.
 * The index starts at 0.
 *
 * ```javascript
 * import {regexIndexOf} from 'util.string';
 * regexIndexOf("abcdefghijk", /k/); // 10
 * ```
 *
 * @param text {string} - the string to search within
 * @param re {RegExp} - the regex object to search with
 * @param i {number} - a starting index value
 * @return {number} the index value location where the regex match was found
 * in the string.  If it is not found, then -1 is returned.
 */
export declare function regexIndexOf(text: string, re: RegExp, start?: number): number;
/**
 * Removes carriage return/line feed (CRLF) characters from the right side of a
 * string.
 *
 * ```javascript
 * import {rstrip} from 'util.string';
 * rstrip("some string\r\n");  // "some string"
 * ```
 *
 * @param str {string} - the string that will have the CRLF removed
 * @return a new string with the CRLF removed
 */
export declare function rstrip(str: string): string;
/**
 * Splits a string into a left an right string tuple based on a given delimiter.
 * The delimter is not included in either string (the first instance encountered)
 * This function will not trim the left/right string as a side effect.
 *
 * ```javascript
 * import {splitInTwo} from 'util.string';
 * let s = "The left side . The right side.";
 * splitInTwo(s, "."); // ["The left side ", " The right side."]
 * ```
 *
 * @param text {string} - the string to split
 * @param delimiter {string} - the string within the text string where the split
 * will occur.
 * @return a tuple containing the left side and the right side of the delimter.
 * both values are a string.  If no delimiter was found then the whole string
 * is returned in the first position of the tuple and the second part is an
 * empty string.
 */
export declare function splitInTwo(text: string, delimiter: string): [string, string];
/**
 * Splits a string into an array of strings based on the newline character.  It
 * will search for a windows and/or unix line endings for the split.
 *
 * ```javascript
 * import {splitNL} from 'util.string';
 * splitNL("a\nb\nc"); // ["a", "b", "c"]
 * ```
 *
 * @param text {string} - the string to split
 * @return {string[]} an array of strings representing each stirng split at the
 * newline characters.  The newline characters are not included.
 */
export declare function splitNL(text: string): string[];
/**
 * Removes whitespaces from the front/end of a string.  This includes
 * whitespace defined by the regex switch \s, end of line characters
 * and zero width non breaking space.  This monkey patches the built in
 * version of trim to handle the unicode character space (\u200b)
 *
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/trim
 *
 * ```javascript
 * import {trim} from 'util.string';
 * trim("\n     test    \n ");  // "test"
 * ```
 *
 * @param text {string} - the string to trim
 * @return {string} the trimmed string
 */
export declare function trim(text: string): string;
